@@ -21,6 +21,7 @@
 #define __GCONF_SEARCH_H__
 
 #include "gconf-editor-window.h"
+#include "gedit-output-window.h"
 #include "gconf-tree-model.h"
 #include "gconf-list-model.h"
 #include <gtk/gtkwidget.h>
@@ -31,19 +32,12 @@ struct _SearchIter {
 	const char *pattern;
 	gboolean search_values;
 	gboolean search_keys;
-	GConfListModel *list_model;
-	GSList *list;
+	GeditOutputWindow *output_window;
+	int res;
 };
 
-typedef struct _SearchPos SearchPos;
-
-struct _SearchPos {
-	GtkTreeIter *tree_iter;
-	guint list_pos;
-};
-
-GSList * gconf_tree_model_build_match_list (GConfTreeModel *tree_model, GConfListModel *list_model, 
-					    const char *pattern, gboolean search_keys, gboolean search_values);
+int gconf_tree_model_build_match_list (GConfTreeModel *tree_model, GeditOutputWindow *output_window,
+				       const char *pattern, gboolean search_keys, gboolean search_values);
 
 
 
